PyMoa-Remote
============

PyMoa-Remote is a library to remotely execute functions e.g. on a Raspberry Pi.

For more information: https://matham.github.io/pymoa-remote/index.html

To install https://matham.github.io/pymoa-remote/installation.html

.. image:: https://img.shields.io/pypi/pyversions/pymoa-remote.svg
    :target: https://pypi.python.org/pypi/pymoa-remote/
    :alt: Supported Python versions

.. image:: https://img.shields.io/pypi/v/pymoa-remote.svg
    :target: https://pypi.python.org/pypi/pymoa-remote/
    :alt: Latest Version on PyPI

.. image:: https://coveralls.io/repos/github/matham/pymoa-remote/badge.svg?branch=master
    :target: https://coveralls.io/github/matham/pymoa-remote?branch=master
    :alt: Coverage status

.. image:: https://github.com/matham/pymoa-remote/workflows/Python%20application/badge.svg
    :target: https://github.com/matham/pymoa-remote/actions
    :alt: Github action status
